// Copyright 2012 Thomas Loy.
//
// This file is part of LastLog.
//
// LastLog is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// LastLog is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with LastLog.  If not, see <http://www.gnu.org/licenses/>.

package edu.self.lastLog;

import java.util.Date;
import org.bukkit.ChatColor;
import org.bukkit.OfflinePlayer;
import org.bukkit.entity.Player;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.player.PlayerLoginEvent;
import org.bukkit.plugin.java.JavaPlugin;

public class LastLogPlugin extends JavaPlugin implements Listener
{
        final public static int pageSize = 10;
        private Command firstlogCommand = null;
        private Command lastlogCommand = null;
        private Command loginfoCommand = null;
        
        @Override
        public void onEnable() {
                firstlogCommand = getCommand("firstlog");
                lastlogCommand = getCommand("lastlog");
                loginfoCommand = getCommand("loginfo");
        }

        @Override
        public void onDisable() {
        }
        
        @Override
        public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {
                if (command == loginfoCommand) {
                        if (args.length == 0) return false;
                        for (String arg : args) {
                                // try match exact name with any known user
                                OfflinePlayer player = getServer().getOfflinePlayer(arg);
                                // if none is found, try and be smart
                                if (!player.hasPlayedBefore()) {
                                        player = getServer().getPlayer(arg);
                                }
                                if (player == null) {
                                        sender.sendMessage("Player " + ChatColor.DARK_GRAY + arg + ChatColor.WHITE + " is unknown");
                                } else {
                                        String name = player.getName();
                                        long first = player.getFirstPlayed();
                                        long last = player.getLastPlayed();
                                        sender.sendMessage("Player " + ChatColor.GOLD + name);
                                        sender.sendMessage("First Login " + "" + ChatColor.YELLOW + new Date(first));
                                        sender.sendMessage("Last Login " + "" + ChatColor.YELLOW + new Date(last));
                                }
                        }
                        return true;
                }
                PlayerList playerList = null;
                boolean lastLog;
                if (command == lastlogCommand) lastLog = true;
                else if (command == firstlogCommand) lastLog = false;
                else return false;
                if (args.length > 1) {
                        return false;
                }
                int pageNumber = 0;
                if (args.length == 1) {
                        try {
                                pageNumber = Integer.parseInt(args[0]) - 1;
                        } catch (IllegalArgumentException iae) {
                                return false;
                        }
                }
                if (pageNumber < 0) return false;
                playerList = new PlayerList(getServer().getOfflinePlayers(), lastLog);
                int pageCount = ((playerList.length() - 1) / pageSize) + 1;
                if (pageNumber > pageCount) {
                        sender.sendMessage("" + ChatColor.RED + "[LastLog] Page " + (pageNumber + 1) + " selected, but only " + pageCount + " available!");
                        return true;
                }
                LastLogSorter sorter = new LastLogSorter(this, sender, playerList, pageNumber, lastLog);
                getServer().getScheduler().scheduleAsyncDelayedTask(this, sorter);
                return true;
        }
}
