// Copyright 2012 Thomas Loy.
//
// This file is part of LastLog.
//
// LastLog is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// LastLog is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with LastLog.  If not, see <http://www.gnu.org/licenses/>.

package edu.self.lastLog;

import java.util.Arrays;
import java.util.Comparator;
import org.bukkit.OfflinePlayer;

public class PlayerList
{
        public class Entry {
                public String name;
                public long time;
                public Entry(String name, long time) {
                        this.name = name;
                        this.time = time;
                }
        }

        private Entry[] playerList;
        static private Comparator<Entry> comparator;

        static {
                comparator = new Comparator<Entry>() {
                        public int compare(Entry a, Entry b) {
                                if (a.time > b.time) return -1;
                                if (a.time < b.time) return 1;
                                return 0;
                        }
                };
        }

        public PlayerList(OfflinePlayer[] playerList, boolean useLastLogin) {
                this.playerList = new Entry[playerList.length];
                int i = 0;
                for (OfflinePlayer player : playerList) {
                        long time = (useLastLogin ? player.getLastPlayed() : player.getFirstPlayed());
                        this.playerList[i++] = new Entry(player.getName(), time);
                }
        }

        public void sort() {
                Arrays.sort(playerList, comparator);
        }

        public void cocktailSort() {
                boolean updated;
                int min = 0;
                int max = playerList.length - 1;
                do {
                        updated = false;
                        for (int i = max; i > min; --i) {
                                Entry a = playerList[i - 1];
                                Entry b = playerList[i];
                                if (comparator.compare(a, b) == 1) {
                                        playerList[i - 1] = b;
                                        playerList[i] = a;
                                        updated = true;
                                }
                        }
                        min += 1;
                        for (int i = min; i < max; ++i) {
                                Entry a = playerList[i];
                                Entry b = playerList[i + 1];
                                if (comparator.compare(a, b) == 1) {
                                        playerList[i] = b;
                                        playerList[i + 1] = a;
                                        updated = true;
                                }
                        }
                        max -= 1;
                } while (updated == true);
        }

        public int length() {
                return playerList.length;
        }

        public Entry getEntry(int index) {
                return playerList[index];
        }

        public Entry getEntry(String name) {
                for (Entry entry : playerList) {
                        if (entry.name.equals(name)) return entry;
                }
                return null;
        }
}
